@@ -61,7 +61,7 @@ plot_elbow <- function(..., burnin = NULL){
   ggplot2::ggplot(df, ggplot2::aes(x = as.factor(.data$n_clusters), y = .data$value)) +
     ggplot2::geom_boxplot() +
     ggplot2::xlab("Number of clusters") +
-    ggplot2::ylab("Within-cluster som of distances") +
+    ggplot2::ylab("Within-cluster sum of distances") +
     ggplot2::ggtitle("Elbow Plot")
 
 
